rhythmmakertools.RestRhythmMaker
================================

.. abjad-lineage:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker

.. autoclass:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.reverse
      ~abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__call__
      ~abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__eq__
      ~abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__format__
      ~abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__makenew__
      ~abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__ne__
      ~abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__repr__

Bases
-----

- :py:class:`rhythmmakertools.DivisionIncisedRestRhythmMaker <abjad.tools.rhythmmakertools.DivisionIncisedRestRhythmMaker.DivisionIncisedRestRhythmMaker>`

- :py:class:`rhythmmakertools.DivisionIncisedRhythmMaker <abjad.tools.rhythmmakertools.DivisionIncisedRhythmMaker.DivisionIncisedRhythmMaker>`

- :py:class:`rhythmmakertools.IncisedRhythmMaker <abjad.tools.rhythmmakertools.IncisedRhythmMaker.IncisedRhythmMaker>`

- :py:class:`rhythmmakertools.RhythmMaker <abjad.tools.rhythmmakertools.RhythmMaker.RhythmMaker>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.reverse
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__call__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__eq__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__format__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__makenew__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__ne__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.RestRhythmMaker.RestRhythmMaker.__repr__
   :noindex:
